voxjar
=======

.. image:: https://readthedocs.org/projects/voxjar/badge/?version=latest
   :target: http://voxjar.readthedocs.io/en/latest/?badge=latest
|

    Python implementation of the `Voxjar`_ `API`_.

    *NOTE*: This library is under active development and should not be considered stable.

.. inclusion-marker-do-not-remove
installation
------------

.. code:: bash

  $ pip install voxjar

documentation
-------------

https://voxjar.readthedocs.io


.. _Voxjar: https://voxjar.com/
.. _API: https://api.voxjar.com:9000/graphiql
